@@ -33,12 +33,13 @@ use strict;
 use Carp             ();
 use File::Spec       ();
 use File::Spec::Unix ();
+use Probe::Perl      ();
 use IPC::Run3        ();
 use Test::Builder    ();
 
 use vars qw{$VERSION @ISA @EXPORT};
 BEGIN {
-	$VERSION = '1.00';
+	$VERSION = '1.04_01';
 	require Exporter;
 	@ISA     = qw( Exporter );
 	@EXPORT  = qw( script_compiles_ok );
@@ -54,6 +55,24 @@ sub import {
 	$self->export_to_level(1, $self, 'script_compiles_ok');
 }
 
+my $perl = undef;
+
+sub perl () {
+	$perl or
+	$perl = Probe::Perl->find_perl_interpreter;
+}
+
+sub path ($) {
+	my $path = shift;
+	unless ( defined $path ) {
+		Carp::croak("Did not provide a script name");
+	}
+	if ( File::Spec::Unix->file_name_is_absolute($path) ) {
+		Carp::croak("Script name must be relative");
+	}
+	File::Spec->catfile( File::Spec->curdir, split /\//, $path );
+}
+
 
 
 
@@ -85,25 +104,16 @@ sub script_compiles_ok {
 	my $unix   = shift;
 	my $name   = shift || "Script $unix compiles";
 	my $path   = path( $unix );
-	my $cmd    = [ $^X, '-c', $path ];
+	my $cmd    = [ perl, '-c', '-Mblib', $path ];
 	my $stderr = '';
 	my $rv     = IPC::Run3::run3( $cmd, \undef, \undef, \$stderr );
-	my $ok     = !! ( $rv and $stderr =~ /syntax OK\s+$/si );
+	my $exit   = $? ? ($? >> 8) : 0;
+	my $ok     = !! ( $rv and $exit == 0 and $stderr =~ /syntax OK\s+$/si );
 	$Test->ok( $ok, $name );
+	$Test->diag( $stderr ) unless $ok;
 	return $ok;
 }
 
-sub path ($) {
-	my $path = shift;
-	unless ( defined $path ) {
-		Carp::croak("Did not provide a script name");
-	}
-	if ( File::Spec::Unix->file_name_is_absolute($path) ) {
-		Carp::croak("Script name must be relative");
-	}
-	File::Spec->catfile( File::Spec->curdir, split /\//, $path );
-}
-
 1;
 
 =pod
@@ -126,7 +136,7 @@ L<prove>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2006 Adam Kennedy.
+Copyright 2006 - 2008 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
